@@ -1,17 +1,18 @@
 package CPAN::Reporter;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.1601'; 
-$VERSION = eval $VERSION;
+$VERSION = '1.17'; 
+$VERSION = eval $VERSION; ## no critic
 
 use Config;
 use CPAN ();
 use CPAN::Version ();
-use File::Basename qw/basename/;
+use File::Basename qw/basename dirname/;
 use File::Find ();
 use File::HomeDir ();
 use File::Path qw/mkpath rmtree/;
 use File::Spec ();
+use File::Temp qw/tempdir/;
 use IO::File ();
 use Parse::CPAN::Meta ();
 use Probe::Perl ();
@@ -23,6 +24,22 @@ use CPAN::Reporter::PrereqCheck ();
 
 use constant MAX_OUTPUT_LENGTH => 50_000;
 
+#--------------------------------------------------------------------------#
+# create temp lib dir for Devel::Autoflush
+# so that PERL5OPT=-MDevel::Autoflush is found by any perl
+#--------------------------------------------------------------------------#
+
+require Devel::Autoflush;
+# directory fixture
+my $Autoflush_Lib = tempdir( 
+  "CPAN-Reporter-lib-XXXX", TMPDIR => 1, CLEANUP => 1 
+);
+# copy Devel::Autoflush to directory or clear autoflush_lib variable
+_file_copy_quiet( 
+  $INC{'Devel/Autoflush.pm'}, 
+  File::Spec->catfile( $Autoflush_Lib, qw/Devel Autoflush.pm/ )
+) or undef $Autoflush_Lib;
+
 #--------------------------------------------------------------------------#
 # public API
 #--------------------------------------------------------------------------#
@@ -139,10 +156,8 @@ HERE
     my $tee_input = Probe::Perl->find_perl_interpreter() .  " $wrapper_name";
     $tee_input .= " $redirect" if defined $redirect;
     {
-      # ensure autoflush
-      local $ENV{PERL5OPT} = $ENV{PERL5OPT} || q{};
-      $ENV{PERL5OPT} .= q{ } if length $ENV{PERL5OPT};
-      $ENV{PERL5OPT} .= "-MDevel::Autoflush";
+      # ensure autoflush if we can
+      local $ENV{PERL5OPT} = _get_perl5opt();
       tee($tee_input, { stderr => 1 }, $temp_out);
     }
 
@@ -209,7 +224,7 @@ sub _compute_make_grade {
     my $result = shift;
     my ($grade,$msg);
     if ( $result->{exit_value} ) {
-        $result->{grade} = "fail";
+        $result->{grade} = "unknown";
         $result->{grade_msg} = "Stopped with an error"
     }
     else {
@@ -219,8 +234,7 @@ sub _compute_make_grade {
 
     _downgrade_known_causes( $result );
     
-    $result->{success} =  $result->{grade} eq 'pass'
-                       || $result->{grade} eq 'unknown';
+    $result->{success} =  $result->{grade} eq 'pass';
     return;
 }
 
@@ -232,7 +246,7 @@ sub _compute_PL_grade {
     my $result = shift;
     my ($grade,$msg);
     if ( $result->{exit_value} ) {
-        $result->{grade} = "fail";
+        $result->{grade} = "unknown";
         $result->{grade_msg} = "Stopped with an error"
     }
     else {
@@ -242,8 +256,7 @@ sub _compute_PL_grade {
 
     _downgrade_known_causes( $result );
     
-    $result->{success} =  $result->{grade} eq 'pass'
-                       || $result->{grade} eq 'unknown';
+    $result->{success} =  $result->{grade} eq 'pass';
     return;
 }
 
@@ -327,7 +340,7 @@ sub _compute_test_grade {
 #--------------------------------------------------------------------------#
 # _dispatch_report
 #
-# Set up Test::Reporter and prompt user for CC, edit, send
+# Set up Test::Reporter and prompt user for edit, send
 #--------------------------------------------------------------------------#
 
 sub _dispatch_report {
@@ -452,7 +465,6 @@ DUPLICATE_REPORT
     # Populate the test report
     $tr->comments( _report_text( $result ) );
     $tr->via( 'CPAN::Reporter ' . $CPAN::Reporter::VERSION );
-    my @cc = _should_copy_author( $result, $config );
 
     # prompt for editing report
     if ( _prompt( $config, "edit_report", $tr->grade ) =~ /^y/ ) {
@@ -467,8 +479,8 @@ DUPLICATE_REPORT
                     : "send_report" ;
     if ( _prompt( $config, $send_config, $tr->grade ) =~ /^y/ ) {
         $CPAN::Frontend->myprint( "CPAN::Reporter: sending test report with '" . $tr->grade . 
-              "' to " . join(q{, }, $tr->address, @cc) . "\n");
-        if ( $tr->send( @cc ) ) {
+              "' to " . $tr->address . "\n");
+        if ( $tr->send() ) {
             CPAN::Reporter::History::_record_history( $result ) 
                 if not $is_duplicate;
         }
@@ -555,6 +567,17 @@ sub _downgrade_known_causes {
         $grade = 'discard';
         $msg = 'No Makefile or Build file found';
     }
+    elsif ( $result->{command} =~ /Build.*?-j/ ) {
+        $grade = 'discard';
+        $msg = '-j is not a valid option for Module::Build (upgrade your CPAN.pm)';
+    }
+    elsif ( 
+      $result->{is_make} && $result->{phase} eq 'make' && 
+      grep { /Makefile out-of-date with respect to Makefile.PL/ } @$output 
+    ) {
+        $grade = 'discard';
+        $msg = 'Makefile out-of-date';
+    }
     
     # store results
     $result->{grade} = $grade;
@@ -607,6 +630,8 @@ my @env_vars= qw(
 
 sub _env_report {
     my @vars_found;
+    # mirror PERL5OPT as in record_command
+    local $ENV{PERL5OPT} = _get_perl5opt();
     for my $var ( @env_vars ) {
         if ( $var =~ m{^/(.+)/$} ) {
             push @vars_found, grep { /$1/ } keys %ENV;
@@ -625,6 +650,41 @@ sub _env_report {
     return $report;
 }
 
+#--------------------------------------------------------------------------#
+# _file_copy_quiet
+#
+# manual file copy -- quietly return undef on failure
+#--------------------------------------------------------------------------#
+
+sub _file_copy_quiet {
+  my ($source, $target) = @_;
+  # ensure we have a target directory
+  mkpath( dirname($target) ) or return;
+  # read source
+  local *FH;
+  open FH, "<$source" or return; ## no critic
+  my $pm_guts = do { local $/; <FH> };
+  close FH;
+  # write target
+  open FH, ">$target" or return; ## no critic
+  print FH $pm_guts;
+  close FH;
+  return 1;
+}
+
+#--------------------------------------------------------------------------#
+# _get_perl5opt
+#--------------------------------------------------------------------------#
+
+sub _get_perl5opt {
+  my $perl5opt = $ENV{PERL5OPT} || q{};
+  if ( $Autoflush_Lib ) {
+    $perl5opt .= q{ } if length $perl5opt;
+    $perl5opt .= "-I$Autoflush_Lib -MDevel::Autoflush";
+  }
+  return $perl5opt;
+}
+
 #--------------------------------------------------------------------------#
 # _has_recursive_make
 #
@@ -939,10 +999,10 @@ HERE
 Thank you for uploading your work to CPAN.  However, attempting to
 test your distribution gave an inconclusive result.  
 
-This could be because you did not define tests, tests could not be 
-found, because your tests were interrupted before they finished, or 
-because the results of the tests could not be parsed.  You may wish to 
-consult the CPAN Testers Wiki:
+This could be because your distribution had an error during the make/build
+stage, did not define tests, tests could not be found, because your tests were
+interrupted before they finished, or because the results of the tests could not
+be parsed.  You may wish to consult the CPAN Testers Wiki:
 
 http://cpantest.grango.org/wiki/CPANAuthorNotes
 HERE
@@ -1027,53 +1087,6 @@ ENDREPORT
     return $output;
 }
 
-
-#--------------------------------------------------------------------------#
-# _should_copy_author
-#--------------------------------------------------------------------------#
-
-sub _should_copy_author {
-    my ($result, $config) = @_;
-
-    # User prompts for action
-    my $author_email = $result->{author_id} 
-                     ? "$result->{author_id}\@cpan.org"
-                     : q{};
-    if ( ! $author_email ) {
-        $CPAN::Frontend->mywarn( "CPAN::Reporter: couldn't determine author_id and won't cc author.\n");
-        return;
-    }
-
-    # Skip if distribution name matches the cc_skipfile
-    if ( $config->{cc_skipfile} && -r $config->{cc_skipfile} ) {
-        my $cc_skipfile = IO::File->new( $config->{cc_skipfile}, "r" );
-        my $dist_id = $result->{dist}->pretty_id;
-        while ( my $pattern = <$cc_skipfile> ) {
-            chomp($pattern);
-            # ignore comments
-            next if substr($pattern,0,1) eq '#';
-            # if it doesn't match, continue with next pattern
-            next if $dist_id !~ /$pattern/i;
-            # if it matches, warn and return
-            $CPAN::Frontend->myprint( << "END_SKIP_DIST" );
-CPAN::Reporter: '$dist_id' matched against the cc_skipfile.  Won't copy author.
-END_SKIP_DIST
-            return;
-        }
-    }
-
-    # Don't copy author on perls with patchlevels
-    return if $Config{perl_patchlevel};
-
-    # Finally, prompt user if necessary
-    if ( _prompt( $config, "cc_author", $result->{grade}, "($author_email)?") =~ /^y/ ) {
-        return $author_email;
-    }
-    else {
-        return;
-    }
-}
-
 #--------------------------------------------------------------------------#
 # _special_vars_report
 #--------------------------------------------------------------------------#
@@ -1144,7 +1157,7 @@ sub _timeout_wrapper {
     # present, as from Tk-ExecuteCommand
     {
       local $SIG{__WARN__} = sub {};  # protect against v-string warning
-      eval "require Proc::ProcessTable; require Proc::Killfam";
+      eval "require Proc::ProcessTable; require Proc::Killfam"; ## no critic
     }
     if ($@) {
         $CPAN::Frontend->mywarn( << 'HERE' );
@@ -1449,21 +1462,20 @@ addition information.
 
 CPAN::Reporter will assign one of the following grades to the report:
 
-* {pass} -- all tests were successful  
+* {pass} -- distribution built and tested correctly
+* {fail} --  distribution failed to test correctly
+* {unknown} -- distribution failed to build, had no test suite or outcome was 
+inconclusive
+* {na} --- distribution is not applicable to this platform and/or 
+version of Perl
 
-* {fail} -- one or more tests failed, one or more test files died during
-testing or no test output was seen
+In returning results of the test suite to CPAN.pm, "pass" and "unknown" are
+considered successful attempts to "make test" or "Build test" and will not
+prevent installation.  "fail" and "na" are considered to be failures and
+CPAN.pm will not install unless forced.
 
-* {na} -- tests could not be run on this platform or version of perl
-
-* {unknown} -- no test files could be found (either t/*.t or test.pl) or 
-a result could not be determined from test output (e.g tests may have hung 
-and been interrupted)
-
-In returning results to CPAN.pm, "pass" and "unknown" are considered successful
-attempts to "make test" or "Build test" and will not prevent installation.
-"fail" and "na" are considered to be failures and CPAN.pm will not install
-unless forced.
+An error from Makefile.PL/Build.PL or make/Build will also be graded as 
+"unknown" and a failure will be signaled to CPAN.pm.
 
 If prerequisites specified in {Makefile.PL} or {Build.PL} are not available,
 no report will be generated and a failure will be signaled to CPAN.pm.
